/**
 * @class LocaleManager
 * @description Represents a singleton that acts as a locale manager for the CLI
 * This provides a convenient way to load in localized strings to be presented
 * to the user.
 */
export class LocaleManager {
    // prevents accidental instantiation
    constructor() { }
    static getInstance() {
        if (!LocaleManager.instance) {
            LocaleManager.instance = new LocaleManager();
        }
        return LocaleManager.instance;
    }
    // set locale?
    setLocale(locale) {
        this.locale = locale;
    }
    getLocale() {
        return this.locale;
    }
    /**
     * @public
     * @param {STORMLocaleData} localeData
     * @description Given locale data, sets the singleton's locale data
     */
    setLocaleData(localeData) {
        this.localeData = localeData;
    }
    /**
     * @public
     * @returns {STORMLocaleData} locale data
     * @description Gets locale data so that it can be used throughout the CLI
     */
    getLocaleData() {
        return this.localeData;
    }
}
//# sourceMappingURL=localeManager.js.map