/**
 * @author SaiForceOne
 * @description ConsoleLogger function that prints formatted logs
 */
// Core & third-party imports
import chalk from 'chalk';
const LOG_CONFIGURATION = {
    error: {
        label: 'damn',
        color: 'redBright',
    },
    info: {
        label: 'okay',
        color: 'blue',
    },
    warning: {
        label: 'ouch',
        color: 'yellow',
    },
    success: {
        label: 'cool',
        color: 'green',
    },
};
/**
 * @description convenience function that gets log message configuration
 * @param logLevel
 */
function getMessageConfiguration(logLevel) {
    return LOG_CONFIGURATION[logLevel] || LOG_CONFIGURATION['info'];
}
/**
 * @description 'Class' definition for logger utility
 */
export class ConsoleLogger {
    /**
     * @description Prints a message to the console, with the appropriate styling
     * @param {string} message
     * @param {LogLevel} logLevel
     */
    static printLog(message, logLevel = 'info') {
        const logConfig = getMessageConfiguration(logLevel);
        const colorName = logConfig.color;
        console.log(`${chalk[colorName].bold(`[${logConfig.label}]: ${message}`)}`);
    }
    static printCLIProcessErrorMessage(message, detail) {
        let output = `⛔ ${chalk.redBright.bold(message)}`;
        if (detail)
            output += `: ${chalk.italic(detail)}`;
        console.log(output);
    }
    static printCLIProcessInfoMessage(message, detail) {
        let output = `ℹ️  ${chalk.dim.bold(message)}`;
        if (detail)
            output += `: ${chalk.italic(detail)}`;
        console.log(output);
    }
    /**
     * @function printCLIProcessWarningMessage
     * @description Prints a warning message with optional detail
     * @param message
     * @param detail
     */
    static printCLIProcessWarningMessage({ message, detail, }) {
        let output = `⚠️  ${chalk.yellowBright.bold(message)}`;
        if (detail)
            output += `: ${chalk.italic(detail)}`;
        console.log(output);
    }
    /**
     * @function printCLIProcessSuccessMessage
     * @description Prints a success message with optional detail
     * @param {string} message
     * @param detail additional information to print out
     */
    static printCLIProcessSuccessMessage({ message, detail, }) {
        let output = `✅ ${chalk.greenBright.bold(message)}`;
        if (detail) {
            output += `: ${chalk.italic(detail)}`;
        }
        console.log(output);
    }
}
//# sourceMappingURL=consoleLogger.js.map